package ppx_expect

  1. Overview
  2. Docs

Module Expect_test_config_types

To configure expect_test, add the following at the top of your .ml file, or in some import.ml:

  module Expect_test_config = struct
    include Expect_test_config
    let pre_redirect_hook () = ...
  end

Note that since all expect test are also inline tests, the inline test configuration also applies to all expect test.

module Upon_unreleasable_issue : sig ... end
module type S = sig ... end